@@ -7,6 +7,8 @@ use autodie;
 
 use Getopt::Long qw/ GetOptions /;
 
+use Path::Tiny qw/ cwd path tempdir tempfile /;
+
 sub do_system
 {
     my ($args) = @_;
@@ -41,12 +43,16 @@ if ($IS_WIN)
     ( $ENV{PKG_CONFIG_PATH} //= '' ) .=
         ";/foo/lib/pkgconfig/;/c/foo/lib/pkgconfig/";
 }
+
+my $cwd           = cwd();
+my $build_dirname = "..${SEP}B";
+path($build_dirname)->remove_tree();
 do_system(
     {
         cmd => [
-                  "cd . && mkdir B && cd B && cmake -DWITH_TEST_SUITE=ON .. "
+"cd . && mkdir $build_dirname && cd $build_dirname && cmake -DWITH_TEST_SUITE=ON \"$cwd\" "
                 . ( defined($cmake_gen) ? qq#-G "$cmake_gen"# : "" )
-                . " && $MAKE && $^X ..${SEP}run-tests.pl"
+                . " && $MAKE && $^X \"$cwd${SEP}run-tests.pl\""
         ]
     }
 );
